---
layout: side-title
title: Class Bindings
color: indigo
align: cm
titlewidth: is-3
---

:: title ::
# Class Bindings

:: content ::

## Binding HTML Classes

- Special enhancements when `v-bind` is used with `class` and
`style`.
- We can pass an object to `v-bind:class` to dynamically toggle classes.

```vue {monaco-run}
<template>
  <ul>
    <li v-for="{ label, purchased, highPriority } in items" class="my-0!"
        :class="{'line-through': purchased, 'text-red': highPriority}">
      {{ label }}
    </li>
  </ul>
</template>
<script setup>
  const items = [ { label: "1kg coffee", purchased: false, highPriority: true },
                  { label: "20 cups", purchased: true, highPriority: false} ]
</script>
```


---
layout: side-title
title: Class Bindings
color: indigo
align: cm
titlewidth: is-3
---

:: title ::
# Class Bindings

:: content ::

## Binding HTML Classes

- The bound object doesn't have to be inline

```vue {monaco-run}
<template>
    <span :class="classObject">Hello World!</span>
</template>
<script setup>
  const classObject = {'font-bold': true, 'text-red': false}
</script>
```

---
layout: side-title
title: Class Bindings
color: indigo
align: cm
titlewidth: is-3
---

:: title ::
# Class Bindings

:: content ::

## Binding HTML Classes

- We can also bind to a computed property that returns an object.

```vue {monaco-run}
<template>
    <span :class="classObject">Hello World!</span>
</template>
<script setup>
  import { ref, computed } from 'vue'
  const isActive = ref(true)
  const classObject = computed(() => ({'font-bold': isActive.value }))
</script>
```


---
layout: side-title
title: Class Bindings
color: indigo
align: cm
titlewidth: is-3
---

:: title ::
# Class Bindings

:: content ::

## Binding to Arrays

- `:class` can be bind to an array to apply a list of classes

```vue {monaco-run}
<template>
    <span :class="[activeClass, errorClass]">Hello World!</span>
</template>
<script setup>
  import { ref, computed } from 'vue'
  const activeClass = ref('font-bold')
  const errorClass = ref('text-red')
</script>
```


---
layout: side-title
title: Class Bindings
color: indigo
align: cm
titlewidth: is-3
---

:: title ::
# Class Bindings

:: content ::

## Binding to Arrays

- It's also possible to use the object syntax inside the array syntax

```vue {monaco-run}
<template>
    <span :class="[{ [activeClass]: isActive }, errorClass]">Hello World!</span>
</template>
<script setup>
  import { ref, computed } from 'vue'
  const isActive = ref(true)
  const activeClass = ref('font-bold')
  const errorClass = ref('text-red')
</script>
```
