---
layout: section
color: indigo
---

# Composition API



---
layout: side-title
title: API Styles
color: indigo
align: cm
titlewidth: is-3
---

:: title ::
# API Styles

:: content ::

## Options API

- Component's logic is defined using an ==object of options== such as `data`,
  `methods`, and `computed`.

````md magic-move
```vue {*}{lines: true}
<script>
export default { }
</script>

<template>
  <button @click="increment">Count is: {{ count }}</button>
</template>
```

```vue {*}{lines: true}
<script>
export default {
  // Properties returned from data() become reactive state
  // and will be exposed on `this`.
  data() {
    return {
      count: 0,
      firstName: 'John',
      lastName: 'Doe'
    }
  },
}
</script>

<template>
  <button @click="increment">Count is: {{ count }}</button>
</template>
```

```vue {*}{lines: true}
<script>
export default {
  data() { /* ... */ },

 // Computed properties are special functions that automatically update when the
 // data they depend on changes
  methods: {
    increment() {
      this.count++
    }
  },
}
</script>

<template>
  <button @click="increment">Count is: {{ count }}</button>
</template>
```

```vue {*}{lines: true}
<script>
export default {
  data() { /* ... */ },
  methods: { /* ... */ },

  // Computed properties are values that are automatically calculated based on
  // other data in your component
  computed: {
    fullName() {
      return this.firstName + ' ' + this.lastName;
    }
  }
}
</script>

<template>
  <button @click="increment">Count is: {{ count }}</button>
</template>
```
````

---
layout: side-title
title: API Styles
color: indigo
align: cm
titlewidth: is-3
---

:: title ::
# API Styles

:: content ::

## Composition API

- Component's logic is defined using ==imported API functions==.
- In SFCs, Composition API is typically used with `<script setup>` which allow
  to use Composition API with less boilerplate.

````md magic-move
```vue {*}{lines:true}
<script setup>
</script>

<template>
  <button @click="increment">Count is: {{ count }}</button>
</template>
```

```vue {*}{lines:true}
<script setup>
import { ref } from 'vue'

// reactive state
const count = ref(0)
</script>

<template>
  <button @click="increment">Count is: {{ count }}</button>
</template>
```

```vue {*}{lines:true}
<script setup>
import { ref } from 'vue'

/** hidden code */

// functions that mutate state and trigger updates
function increment() {
  count.value++
}
</script>

<template>
  <button @click="increment">Count is: {{ count }}</button>
</template>
```

```vue {*}{lines:true}
<script setup>
import { ref, computed } from 'vue'

/** hidden code */

// computed properties
const fullName = computed(() => `${firstName.value} ${lastName.value}`)
</script>

<template>
  <button @click="increment">Count is: {{ count }}</button>
</template>
```
````

---
src: ./reactivity.md
---

---
src: ./directives/v-for.md
---

---
src: ./directives/v-if.md
---

---
src: ./class_binding.md
---

---
src: ./style_binding.md
---

---
src: ./event_handling.md
---