---
layout: side-title
title: Conditional Rendering
color: indigo
align: cm
titlewidth: is-3
---

:: title ::
# Conditional Rendering

:: content ::

## Directive `v-if`

- The block is rendered if the directive's expression is a
**truthy** value.

- The `v-else` and `v-else-if` directives can also be used.

```vue {monaco-run} { runnerOptions: { wordWrap:'on'} }
<template>
  <div class="flex justify-between items-center">
    <span v-if="status === 'success'">Operation was successful!</span>
    <span v-else-if="status === 'error'">An error has occurred.</span>
    <span v-else>No status provided.</span>
    <div class="space-x-1">
      <button class="btn-blue" @click="status = 'success'">Success</button>
      <button class="btn-blue" @click="status = 'error'">Error</button>
    </div>
  </div>
</template>
<script setup>
  import { ref } from 'vue'
  const status = ref("")
</script>
```


---
layout: side-title
title: Conditional Rendering
color: indigo
align: cm
titlewidth: is-3
---

:: title ::
# Conditional Rendering

:: content ::

## Directive `v-show`

- Unlike `v-if`, `v-show` will always be rendered and remain in the DOM. It only
toggles the `display` CSS property of the element
- It doesn't support the `<template>` element, nor does it work with `v-else`.


```vue {monaco-run} { runnerOptions: { wordWrap:'on'} }
<template>
  <div class="flex justify-between items-center">
    <button class="btn-blue" @click="isVisible = !isVisible">Toggle</button>
    <span v-show="isVisible">Hello! This message is visible.</span>
  </div>
</template>
<script setup>
  import { ref } from 'vue'
  const isVisible = ref(true)
</script>
```


---
layout: side-title
title: Conditional Rendering
color: indigo
align: cm
titlewidth: is-3
---

:: title ::
# Conditional Rendering

:: content ::

## `v-if` vs. `v-show`

<v-clicks>

- `v-if` is **"real" conditional rendering** because it ensures that event
listeners and child components inside the conditional block are properly
destroyed and re-created during toggles.

- `v-if` is also **lazy**: if the condition is `false` on initial render, it
will not do anything - the conditional block won't be rendered until the
condition becomes `true` for the first time.

- In comparison, `v-show` is **much simpler** -- the element is always rendered
regardless of initial condition, with CSS-based toggling.

- Generally speaking, `v-if` has higher toggle costs while `v-show` has higher
initial render costs.

- So prefer `v-show` if you need to toggle something very
often, and prefer `v-if` if the condition is unlikely to change at runtime.

</v-clicks>
