---
layout: section
color: indigo
---

# Setting up the Environment


---
layout: side-title
title: Installation
color: indigo
titlewidth: is-3
align: cm
---

:: title ::
# Installation

:: content ::

## Node.js

```bash
# Download and install nvm:
❯ curl -o- https://raw.githubusercontent.com/nvm-sh/nvm/v0.40.2/install.sh | bash

# in lieu of restarting the shell
❯ \. "$HOME/.nvm/nvm.sh"

# Download and install Node.js:
❯ nvm install 24

# Verify the Node.js version:
❯ node -v # Should print "v24.0.2".
❯ nvm current # Should print "v24.0.2".

# Verify npm version:
❯ npm -v # Should print "11.3.0".
```

<div class="mt-5 flex justify-center">
  <QRCode value="https://nodejs.org/fr/download" :size="100" render-as="svg"/>
</div>

---
layout: side-title
title: Installation
color: indigo
align: cm
titlewidth: is-3
---
:: title ::
# Installation

:: content ::

## Vue.js


This command will install and execute `create-vue`, the official Vue project
scaffolding tool.

```bash
❯ npm create vue@latest
```

<div class="mt-5 flex justify-center">
  <QRCode value="https://vuejs.org/guide/quick-start.html#creating-a-vue-application" :size="100" render-as="svg"/>
</div>

---
layout: side-title
title: Installation
color: indigo
align: cm
titlewidth: is-3
---
:: title ::
# Installation

:: content ::

## Vue.js

````md magic-move
```bash
┌  Vue.js - The Progressive JavaScript Framework
│
◆  Project name (target directory):
│  <your-project-name>
└
```
```bash {6-7|10|14|15}
┌  Vue.js - The Progressive JavaScript Framework
│
◇  Project name (target directory):
│  vue-project
│
◆  Select features to include in your project:
│  (↑/↓ to navigate, space to select, a to toggle all, enter to confirm)
│  ◻ TypeScript
│  ◻ JSX Support
│  ◼ Router (SPA development)
│  ◻ Pinia (state management)
│  ◻ Vitest (unit testing)
│  ◻ End-to-End Testing
│  ◼ ESLint (error prevention)
│  ◼ Prettier (code formatting)
└
```
```bash {11-12}
┌  Vue.js - The Progressive JavaScript Framework
│
◇  Project name (target directory):
│  vue-project
│
◇  Select features to include in your project:
│  (↑/↓ to navigate, space to select, a to toggle all, enter to confirm)
│  Router (SPA development), ESLint (error prevention), Prettier (code formatting)
│
◆  Install Oxlint for faster linting? (experimental)
│  ○ Yes / ● No
└
```
```bash {14-21}
┌  Vue.js - The Progressive JavaScript Framework
│
◇  Project name (target directory):
│  test
│
◇  Select features to include in your project:
│  (↑/↓ to navigate, space to select, a to toggle all, enter to confirm)
│  Router (SPA development), ESLint (error prevention), Prettier (code formatting)
│
◇  Install Oxlint for faster linting? (experimental)
│  No

Scaffolding project in /Users/himito/vue-project...
│
└  Done. Now run:

   cd test
   npm install
   npm run format
   npm run dev
```
````

---
layout: side-title
title: Installation
color: indigo
align: cm
titlewidth: is-3
---
:: title ::
# Installation

:: content ::

## Vue.js

```bash
❯ npm install
❯ npm run dev
```
<v-click>
<div class="flex justify-center mt-4">
  <img src="/images/vue_new.png" class="ns-c-border">
</div>
</v-click>

---
layout: side-title
title: Installation
color: indigo
align: cm
titlewidth: is-3
---
:: title ::
# Installation

:: content ::

## Vue.js

The newly created Vue project has the following folders and files:


````md magic-move
```bash
.
├── eslint.config.ts
├── index.html
├── jsconfig.json
├── package.json
├── public
├── src
└── vite.config.js
```
```bash{1,2|3|4|5|6|7|8}
.
├── eslint.config.ts    # Configures ESLint for code linting—rules
├── index.html          # The HTML entry point
├── jsconfig.json       # Configure JavaScript language features
├── package.json        # Lists project dependencies, scripts, metadata, and more
├── public              # Static files (favicon, robots.txt, etc.)
├── src                 # Main source code lives here
└── vite.config.js      # Vite’s config file (tool that runs and builds the app)
```
```bash {7-13}
.
├── eslint.config.ts
├── index.html
├── jsconfig.json
├── package.json
├── public
├── src                 # Main source code lives here
│   ├── App.vue
│   ├── assets
│   ├── components
│   ├── main.js
│   ├── router
│   └── views
└── vite.config.js
```
```bash {8|9|10|11|12|13}
.
├── eslint.config.ts
├── index.html
├── jsconfig.json
├── package.json
├── public
├── src                 # Main source code lives here
│   ├── App.vue         # Root Vue component
│   ├── assets          # Static assets used in the app
│   ├── components      # Reusable Vue components
│   ├── main.js         # App bootstrap file
│   ├── router          # Vue Router setup (routes config, guards, etc.)
│   └── views           # Page-level components
└── vite.config.js
```
````

---
layout: side-title
title: Installation
color: indigo
align: cm
titlewidth: is-3
---
:: title ::
# Installation

:: content ::

## IDE Support

- The recommended IDE setup is ==VS Code== + the `Vue - Official` extension
<VScodePlugin logo="vue_logo.png" title="Vue - Official" description="Language Support for Vue" publisher="Vue" itemName="Vue.volar" sponsorUrl="https://github.com/sponsors/johnsoncodehk" publisherUrl="https://vuejs.org" numberOfReviews=111 numberOfInstalls="5,057,023" numberOfStars=3 />

<div v-click>

- ==WebStorm== also provides great built-in support for Vue SFCs.
- Other IDEs that support the ==Language Service Protocol (LSP)== can also leverage
  Volar's core functionalities via LSP:
  - vim / Neovim support via `coc-volar`.
  - emacs support via `lsp-mode`

</div>

---
layout: side-title
title: Installation
color: indigo
align: cm
titlewidth: is-3
---
:: title ::
# Installation

:: content ::

## Linting

- The Vue team maintains `eslint-plugin-vue`, an ESLint plugin that supports
  SFC-specific linting rules.

<GithubCard owner="vuejs" name="eslint-plugin-vue" description="Official ESLint plugin for Vue.js" logo="vue_logo.png" contributors=228 issues=181 stars="5k" forks=681 />

---
layout: side-title
title: Installation
color: indigo
align: cm
titlewidth: is-3
---
:: title ::
# Installation

:: content ::

## Linting

- The VS Code extension ==ESLint== gives linter feedback right in the editor
  during development.

<VScodePlugin logo="eslint_logo.png" title="ESLint" description="Integrates ESLint JavaScript into VS Code." itemName="dbaeumer.vscode-eslint" publisher="Microsoft" publisherUrl="https://microsoft.com" numberOfReviews=242 numberOfInstalls="42,333,852" numberOfStars=4 />

---
layout: side-title
title: Installation
color: indigo
align: cm
titlewidth: is-3
---
:: title ::
# Installation

:: content ::

## Formatting

- The `Vue - Official` VS Code extension provides formatting for Vue SFCs out of the box.
- ==Prettier== provides built-in Vue SFC formatting support.

<GithubCard owner="vuejs" name="eslint-config-prettier" description="eslint-config-prettier for create-vue setups" logo="vue_logo.png" contributors=9 issues=1 stars="74" forks=10 />


---
layout: side-title
title: Installation
color: indigo
align: cm
titlewidth: is-3
---
:: title ::
# Installation

:: content ::

## Formatting

- The VS Code extension ==Prettier== ensures your code adheres to formatting
  standards without additional effort.

<VScodePlugin logo="prettier_logo.png" title="Prettier - Code formatter" description="Code formatter using prettier" itemName="esbenp.prettier-vscode" publisher="Prettier" publisherUrl="https://prettier.io" numberOfReviews=479 numberOfInstalls="56,160,593" numberOfStars=3 sponsorUrl="https://opencollective.com/prettier" />



---
layout: side-title
title: Installation
color: indigo
align: cm
titlewidth: is-3
---
:: title ::
# Installation

:: content ::

## Tailwind CSS

- A **utility-first CSS framework** for rapidly building custom interfaces.
- Instead of writing custom CSS, you use **predefined utility classes**.
- Designed for **developer productivity and consistency**.

```vue {monaco-run}
<template>
  <div class="p-4 bg-white border-1 border-gray-9 rounded-lg">Hello</div>
</template>
```

<div class="mt-5 flex justify-center">
  <QRCode value="https://tailwindcss.com/docs/installation/using-vite" :size="100" render-as="svg"/>
</div>



---
layout: side-title
title: Installation
color: indigo
align: cm
titlewidth: is-3
---
:: title ::
# Installation

:: content ::

## Tailwind CSS



- Install `tailwindcss` and `@tailwindcss/vite` via `npm`

```bash
❯ npm install tailwindcss @tailwindcss/vite
```

- Add the `@tailwindcss/vite` plugin to `vite.config.ts`

```js {*}{lines:true}
import { defineConfig } from 'vite'
import tailwindcss from '@tailwindcss/vite'

export default defineConfig({
  plugins: [
    tailwindcss(),
  ],
})
```

- Add an `@import` to your CSS file that imports Tailwind CSS.
```css
@import "tailwindcss";
```
