---
layout: side-title
title: Style Bindings
color: indigo
align: cm
titlewidth: is-3
---

:: title ::
# Style Bindings

:: content ::

## Binding to Objects

- `:style` property supports binding to JavaScript object values.

```vue {monaco-run}
<template>
    <span :style="{ 'font-size': fontSize + 'px' }">Hello World!</span>
</template>
<script setup>
  import { ref, computed } from 'vue'
  const fontSize = ref(18)
</script>
```

<v-click>

- `:style` directives can also coexist with regular `style` attributes.

```vue {monaco-run}
<template>
    <span style="color: red" :style="'font-size: 18px'">Hello World!</span>
</template>
```

</v-click>



---
layout: side-title
title: Style Bindings
color: indigo
align: cm
titlewidth: is-3
---

:: title ::
# Style Bindings

:: content ::

## Binding to Arrays

- `:style` can be bind to an array of multiple style objects


```vue {monaco-run}
<template>
  <span :style="[baseStyle, activeStyle]">Hello World!</span>
</template>
<script setup>
import { reactive } from 'vue';

const baseStyle = reactive({
  color: 'blue',
});

const activeStyle = reactive({
  fontWeight: 'bold',
  fontSize: '14px'
});
</script>
```
